==> ctgGEM_0.99.3.tar.gz: ctgGEM/R/plotOriginalTree.R <==
#' Display Original ctgGEM Plots
#'
#' Displays the original plots created by the ctgGEM package and
#' stored in the [originalTrees] slot of a ctgGEMset object.
#'
#' @note In order to reproduce original oncoNEM trees or destiny plots, the
#'     respective package(s) must be installed.
#'
#' @param dataSet a ctgGEMset object
#' @param treeType the type of tree to display.  Must be one of
#'     \code{names(originalTrees(dataSet))}
#'
#' @return For \code{treeType = "destinyDM"} and
#'     \code{treeType = "destinyDPT"}, returns \code{NULL}. For
#'     \code{treeType = "cellTreeTopics"} or \code{"cellTreeGrouping"}, an
#'     igraph object. For all other tree types, a ggplot2::ggplot object.
#' @export
#' @include ctgGEMset-class.R
#' @include ctgGEMset-methods.R
#' @importFrom graphics plot.new
#' @examples
#' # load HSMMSingleCell package
#' library(HSMMSingleCell)
#'
#' # load the data for cellTree, TSCAN, and monocle:
#' data(HSMM_expr_matrix)
#' data(HSMM_sample_sheet)
#' data(HSMM_gene_annotation)
#'
#' # construct a ctgGEMset
#' dataSet <- ctgGEMset(exprsData = HSMM_expr_matrix,
#'                         phenoData = HSMM_sample_sheet,
#'                         featureData = HSMM_gene_annotation)
#'
#' TSCANinfo(dataSet) <- "ENSG00000000003.10"
#'
#' # run generate_tree()
#' dataSet <- generate_tree(dataSet = dataSet, treeType = "TSCAN")
#'
#' # view names of original trees
#' names(originalTrees(dataSet))
#'
#' # plot original trees
#' plotOriginalTree(dataSet, "TSCANclustering")
#' plotOriginalTree(dataSet, "TSCANsingleGene")
plotOriginalTree <- function(dataSet, treeType) {
    stopifnot(is(dataSet, "ctgGEMset"))
    stopifnot(treeType %in% names(originalTrees(dataSet)))
    treeData <- originalTrees(dataSet)[[treeType]]

    # ANY CHANGES MADE IN THE FOLLOWING CODE MUST BE CHECKED FOR
    # COMPATIBILITY WITH THEIR RESPECTIVE make METHODS

    if (treeType == "cellTreeTopics") {
        if (!requireNamespace("cellTree", quietly = TRUE)) {
            stop(
            "Package 'cellTree' is required to view an original cellTree plot.
            See ctgGEM vignette for details on installing 'cellTree'",
            call. = FALSE)
        }
        cellTree::ct.plot.topics(treeData)
    } else if (treeType == "cellTreeGrouping") {
        if (!requireNamespace("cellTree", quietly = TRUE)) {
            stop(
            "Package 'cellTree' is required to view an original cellTree plot.
            See ctgGEM vignette for details on installing 'cellTree'",
            call. = FALSE)
        }
        cellTree::ct.plot.grouping(treeData)
    } else if (treeType == "destinyDM") {
        if (!requireNamespace("destiny", quietly = TRUE)) {
            stop(
                "Package 'destiny' is required to view an original destiny plot.
                See ctgGEM vignette for details on installing 'destiny'",
                call. = FALSE
            )
        }
        # extract the actual tree data instead of placeholder
        treeData <- originalTrees(dataSet)[["destinyDPT"]]@dm
        plot.new()
        destiny::plot(treeData, main = title(main = "DiffusionMap"))
    } else if (treeType == "destinyDPT") {
        if (!requireNamespace("destiny", quietly = TRUE)) {
            stop(
                "Package 'destiny' is required to view an original destiny plot.
                See ctgGEM vignette for details on installing 'destiny'",
                call. = FALSE
            )
        }
        destiny::plot(treeData)

    } else if (grepl("sincell", treeType)) {
        igraph::plot.igraph(
            treeData,
            main = treeData$main,
            vertex.label = treeData$vertex.label,
            vertex.size = treeData$vertex.size,
            edge.color = treeData$edge.color,
            edge.width = treeData$edge.width,
            vertex.label.cex = treeData$vertex.label.cex,
            layout = treeData$layout
        )
    } else {
        # if it's not a special case, it's in ggplot format
        graphics::plot(treeData)
    }
}

==> ctgGEM_1.4.0.tar.gz: ctgGEM/R/plotOriginalTree.R <==
#' Display Original ctgGEM Plots
#'
#' Displays the original plots created by the ctgGEM package and
#' stored in the [originalTrees] slot of a ctgGEMset object.
#'
#' @note In order to reproduce original oncoNEM trees or destiny plots, the
#'     respective package(s) must be installed.
#'
#' @param dataSet a ctgGEMset object
#' @param treeType the type of tree to display.  Must be one of
#'     \code{names(originalTrees(dataSet))}
#'
#' @return For \code{treeType = "destinyDM"} and
#'     \code{treeType = "destinyDPT"}, returns \code{NULL}. 
#'     For all other tree types, a ggplot2::ggplot object.
#' @export
#' @include ctgGEMset-class.R
#' @include ctgGEMset-methods.R
#' @importFrom graphics plot.new
#' @examples
#' # load HSMMSingleCell package
#' library(HSMMSingleCell)
#'
#' # load the data for TSCAN and monocle:
#' data(HSMM_expr_matrix)
#' data(HSMM_sample_sheet)
#' data(HSMM_gene_annotation)
#'
#' # construct a ctgGEMset
#' dataSet <- ctgGEMset(exprsData = HSMM_expr_matrix,
#'                         phenoData = HSMM_sample_sheet,
#'                         featureData = HSMM_gene_annotation)
#'
#' TSCANinfo(dataSet) <- "ENSG00000000003.10"
#'
#' # run generate_tree()
#' dataSet <- generate_tree(dataSet = dataSet, treeType = "TSCAN")
#'
#' # view names of original trees
#' names(originalTrees(dataSet))
#'
#' # plot original trees
#' plotOriginalTree(dataSet, "TSCANclustering")
#' plotOriginalTree(dataSet, "TSCANsingleGene")
plotOriginalTree <- function(dataSet, treeType) {
    stopifnot(is(dataSet, "ctgGEMset"))
    stopifnot(treeType %in% names(originalTrees(dataSet)))
    treeData <- originalTrees(dataSet)[[treeType]]

    # ANY CHANGES MADE IN THE FOLLOWING CODE MUST BE CHECKED FOR
    # COMPATIBILITY WITH THEIR RESPECTIVE make METHODS
# 
#     if (treeType == "cellTreeTopics") {
#         if (!requireNamespace("cellTree", quietly = TRUE)) {
#             stop(
#             "Package 'cellTree' is required to view an original cellTree plot.
#             See ctgGEM vignette for details on installing 'cellTree'",
#             call. = FALSE)
#         }
#         cellTree::ct.plot.topics(treeData)
#     } else if (treeType == "cellTreeGrouping") {
#         if (!requireNamespace("cellTree", quietly = TRUE)) {
#             stop(
#             "Package 'cellTree' is required to view an original cellTree plot.
#             See ctgGEM vignette for details on installing 'cellTree'",
#             call. = FALSE)
#         }
#         cellTree::ct.plot.grouping(treeData)
#     } else 
    if (treeType == "destinyDM") {
        if (!requireNamespace("destiny", quietly = TRUE)) {
            stop(
                "Package 'destiny' is required to view an original destiny plot.
                See ctgGEM vignette for details on installing 'destiny'",
                call. = FALSE
            )
        }
        # extract the actual tree data instead of placeholder
        treeData <- originalTrees(dataSet)[["destinyDPT"]]@dm
        plot.new()
        destiny::plot(treeData, main = title(main = "DiffusionMap"))
    } else if (treeType == "destinyDPT") {
        if (!requireNamespace("destiny", quietly = TRUE)) {
            stop(
                "Package 'destiny' is required to view an original destiny plot.
                See ctgGEM vignette for details on installing 'destiny'",
                call. = FALSE
            )
        }
        destiny::plot(treeData)

    } else if (grepl("sincell", treeType)) {
        igraph::plot.igraph(
            treeData,
            main = treeData$main,
            vertex.label = treeData$vertex.label,
            vertex.size = treeData$vertex.size,
            edge.color = treeData$edge.color,
            edge.width = treeData$edge.width,
            vertex.label.cex = treeData$vertex.label.cex,
            layout = treeData$layout
        )
    } else {
        # if it's not a special case, it's in ggplot format
        graphics::plot(treeData)
    }
}
